# Fx vol package

This is a simple fx vol package to illustrate the Lee extrapolation. You need to export your own data
in order to test it , the package just manipulate data, extrapolate the smile for various smile axis :
delta spot, strike and logMoneyness and plot the smile obtain. You can play with the factor that will be apply on both wings.